@@ -85,7 +85,7 @@ class CreateCluster(command.Command):
         parser.add_argument('--labels',
                             metavar='<KEY1=VALUE1,KEY2=VALUE2;KEY3=VALUE3...>',
                             action='append',
-                            help=_('Arbitrary labels in the form of key=value'
+                            help=_('Arbitrary labels in the form of key=value '
                                    'pairs to associate with a cluster '
                                    'template. May be used multiple times.'))
         parser.add_argument('--keypair',
@@ -159,10 +159,16 @@ class CreateCluster(command.Command):
         parser.add_argument(
             '--master-lb-enabled',
             dest='master_lb_enabled',
-            action='store_true',
-            default=False,
-            help=_('Indicates whether created clusters should have '
-                   'a loadbalancer for API.'))
+            action='append_const',
+            default=[],
+            const=False,
+            help=_('Enable master LB creation on the new cluster'))
+        parser.add_argument(
+            '--master-lb-disabled',
+            dest='master_lb_enabled',
+            action='append_const',
+            const=False,
+            help=_('Disable master LB creation on the new cluster'))
 
         return parser
 
@@ -215,6 +221,20 @@ class CreateCluster(command.Command):
         if parsed_args.master_lb_enabled:
             args["master_lb_enabled"] = parsed_args.master_lb_enabled
 
+        if len(parsed_args.master_lb_enabled) > 1:
+            raise exceptions.InvalidAttribute(
+                '--master-lb-enabled and '
+                '--master-lb-disabled are '
+                'mutually exclusive and '
+                'should be specified only once.')
+        elif len(parsed_args.master_lb_enabled) == 1:
+            args['master_lb_enabled'] = parsed_args.master_lb_enabled[0]
+            if (not args['master_lb_enabled'] and
+                    parsed_args.master_count > 1):
+                raise exceptions.InvalidAttribute(
+                    'Master node count can only be one if master '
+                    'loadbalancer is disabled.')
+
         cluster = mag_client.clusters.create(**args)
         print("Request to create cluster %s accepted"
               % cluster.uuid)
@@ -462,8 +482,8 @@ class ResizeCluster(command.Command):
             '--nodes-to-remove',
             metavar='<Server UUID>',
             action='append',
-            help=_("Server ID of the nodes to be removed. Repeat to add"
-                   "more server ID"))
+            help=_('Server ID of the nodes to be removed. Repeat to add '
+                   'more server ID'))
 
         parser.add_argument(
             '--nodegroup',
